### Encoding: latin1

### Name: ecespa
### Title: Functions for spatial point pattern analysis in ecology
### Aliases: ecespa ecespa
### Keywords: package spatial

### ** Examples

## Not run: 
##D 
##D ###  Summarize the joint pattern of points and marks at different scales
##D ###  with the normalized mark-weighted K-function (Penttinen, 2006). 
##D ###  Compare this function in two consecutive cohorts of Helianthemum
##D ###  squamatum seedlings:
##D 
##D data(seedlings1)
##D 
##D data(seedlings2)
##D   
##D s1km <- Kmm(seedlings1, r=1:100)
##D   
##D s2km <- Kmm(seedlings2, r=1:100)
##D   
##D plot(s1km$r, s1km$Kmm.n, type="l", lty=1, lwd=3, ylim=c(0.6, 1.2),
##D          xlab="r (cm)", ylab= expression (K[mm](r)),
##D          main="Mark-weighted K-function of Hs seedling cohorts")
##D   
##D lines(s2km$r, s2km$Kmm.n, lty=2,lwd=3)
##D   
##D abline(h=1, lwd=2, lty=3)
##D   
##D legend(x=60, y=1.2, legend=c("HsC1", "HsC2", "Ho:"),
##D          lty=c(1, 2, 3), lwd=c(3, 2, 2), bty="n")
##D 
##D 
##D ###  Explore the local relationships between marks and locations (e.g. size 
##D ###  of one cohort of H. squamatum seedlings). Map the marked point pattern 
##D ###  to a random field for visual inspection, with the normalized mark-sum
##D ###  measure (Penttinen, 2006).
##D 
##D data(seedlings1)
##D 
##D seed.m <- marksum(seedlings1, R=20)
##D 
##D marksum.plot(seed.m, what="marksum")  # raw mark-sum measure
##D 
##D marksum.plot(seed.m, what="pointsum") # point sum measure
##D    
##D marksum.plot(seed.m,  what="normalized") # normalized  mark-sum measure
##D 
##D 
##D 
##D ###  Test asociation/repulsion between  a "fixed" pattern (e.g. adult
##D ###  H. squamatum plants) and a "variable" pattern (e.g. of surviving and 
##D ###  dead seedlings), with 2.5% and 97.5% envelopes of 999 random 
##D ###  labellings (De la Cruz & al. 2007).
##D 
##D data(Helianthemum)
##D 
##D cosa <- K012(Helianthemum, fijo="adultHS", i="deadpl", j="survpl",
##D              r=seq(0,200,le=201), nsim=999, nrank=25, correction="isotropic")
##D 
##D plot(cosa$k01, sqrt(./pi)-r~r,  col=c(3, 1, 3), lty=c(3, 1, 3), las=1,
##D          ylab=expression(L[12]), xlim=c(0, 200), 
##D          main="adult HS vs. dead seedlings")
##D 
##D plot(cosa$k02, sqrt(./pi)-r~r, col=c(3, 1, 3), lty=c(3, 1, 3), las=1, 
##D          ylab=expression(L[12]), xlim=c(0, 200),
##D          main="adult HS vs. surviving seedlings")
##D 
##D 
##D 
##D ###  Test differences of agregation and segregation between two patterns, 
##D ###  e.g. surviving and dying H. squamatum seedlings (De la Cruz & al. 2007). 
##D 
##D data(Helianthemum)
##D 
##D cosa12 <- K1K2(Helianthemum, j="deadpl", i="survpl", r=seq(0,200,le=201),
##D                  nsim=99, nrank=1, correction="isotropic")
##D 
##D plot(cosa12$k1k2, lty=c(2, 1, 2), col=c(2, 1, 2), xlim=c(0, 200),
##D          main= "survival- death")
##D 
##D plot(cosa12$k1k12, lty=c(2, 1, 2), col=c(2, 1, 2), xlim=c(0, 200),
##D          main="segregation of surviving seedlings")
##D 
##D plot(cosa12$k2k12, lty=c(2, 1, 2), col=c(2, 1, 2), xlim=c(0, 200),
##D          main= "segregation of dying seedlings")
##D 
##D 
##D 
##D ###  Test segregation based on the counts in the contingency table
##D ###  of nearest neighbors in a multitype point pattern (Dixon, 2002)
##D 
##D data(swamp)
##D 
##D dixon2002(swamp,nsim=99)
##D 
##D 
##D 
##D ###  Fit the Poisson cluster point process to a point pattern with the method of
##D ###  minimum contrast (Diggle 2003).
##D 
##D data(gypsophylous)
##D 
##D # Estimate K function ("Kobs").
##D 
##D gyps.env <- envelope(gypsophylous, Kest, correction="iso")
##D 
##D plot(gyps.env, sqrt(./pi)-r~r)
##D 
##D # Fit Poisson Cluster Process. The limits of integration 
##D # rmin and rmax are setup to 0 and 60, respectively. 
##D 
##D cosa.pc <- pc.estK(Kobs = gyps.env$obs[gyps.env$r<=60],
##D                            r = gyps.env$r[gyps.env$r<=60])
##D 
##D # Add fitted Kclust function to the plot.
##D 
##D lines(gyps.env$r,sqrt(Kclust(gyps.env$r, cosa.pc$sigma2,cosa.pc$rho)/pi)-gyps.env$r,
##D        lty=2, lwd=3, col="purple")
##D 
##D # A kind of pointwise test of the gypsophylous pattern been a realisation
##D # of the fitted model, simulating with sim.poissonc and using function J (Jest).
##D 
##D gyps.env.sim <- envelope(gypsophylous, Jest, 
##D                     simulate=expression(sim.poissonc(gypsophylous,
##D                     sigma=sqrt(cosa.pc$sigma2), rho=cosa.pc$rho)))
##D 
##D plot(gyps.env.sim,  main="")
##D 
## End(Not run)



